@@ -90,8 +90,8 @@ class SharedCommand(BaseCommand):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.params.insert(0, click.core.Option(param_decls=(
-            "-f", "--cmd-files"), multiple=True, required=True,
-            help="Files containing a list of commands.")
+            "-f", "--cmd-files"), multiple=True, required=True, type=str, default=Config().defaults.cmdfiles,
+            help=f"File(s) containing a list of commands. Default: {Config().defaults.cmdfiles}")
         )
         self.params.insert(1, click.core.Option(param_decls=(
             "-i", "--jobids"), multiple=True, type=str, callback=resolve_jobids,
@@ -108,7 +108,14 @@ def cli():
     pass
 
 
-@click.command(cls=SharedCommand, help="Run commands")
+def are_jobids_specified(jobids: List):
+    are_specified = len(jobids) > 0
+    if not are_specified:
+        click.echo("This operation requires specification of jobids with -i or --jobids")
+    return are_specified
+
+
+@click.command(cls=SharedCommand, help="Run jobs")
 @click.option("-u", "--user", default=Config().defaults.username,
               help="Run command job(s) for the given user.")
 @click.option("-p", "--priority", default=Config().defaults.priority,
@@ -121,37 +128,42 @@ def cli():
 @click.option("-x", "--ignore_errors", default=False, flag_value=True,
               help="Run command job(s) despite reported errors.")
 def run(cmd_files, jobids, workers, user, priority, reservation, duration, ignore_errors):
-    if is_config_valid():
+    if are_jobids_specified(jobids=jobids) and is_config_valid():
         solitude.core.run(cmd_files=cmd_files, jobids=jobids, workers=workers, user=user,
                           priority=priority, reservation=reservation,
                           duration=duration, ignore_errors=ignore_errors,
                           cfg=Config(), cache_file=Config().cache_path)
 
 
-@click.command(cls=SharedCommand, help="Extend running commands")
+@click.command(cls=SharedCommand, help="Extend running jobs")
 def extend(cmd_files, jobids, workers):
-    if is_config_valid():
+    if are_jobids_specified(jobids=jobids) and is_config_valid():
         solitude.core.extend(cmd_files=cmd_files, jobids=jobids, workers=workers,
                              cfg=Config(), cache_file=Config().cache_path)
 
 
-@click.command(cls=SharedCommand, help="Stop running commands")
+@click.command(cls=SharedCommand, help="Stop running jobs")
 def stop(cmd_files, jobids, workers):
-    if is_config_valid():
+    if are_jobids_specified(jobids=jobids) and is_config_valid():
         solitude.core.stop(cmd_files=cmd_files, jobids=jobids, workers=workers,
                            cfg=Config(), cache_file=Config().cache_path)
 
 
-@click.command(cls=SharedCommand, help="List commands")
+@click.command(name="list", cls=SharedCommand, help="List jobs")
 @click.option("-s", "--selected-only", "selected_only", flag_value=True, default=False,
               help="Only display the jobs indicated by jobids. Default=No")
-def list(cmd_files, jobids, workers, selected_only):
+def list_jobs(cmd_files, jobids, workers, selected_only):
     if is_config_valid():
         solitude.core.list_jobs(cmd_files=cmd_files, jobids=jobids, workers=workers, selected_only=selected_only,
                                 cfg=Config(), cache_file=Config().cache_path)
 
 
-@click.group(cls=BaseGroup, help="Configure the tool")
+@click.group(cls=BaseGroup, help="Job operations")
+def job():
+    pass
+
+
+@click.group(cls=BaseGroup, help="Configuration operations")
 def config():
     pass
 
@@ -170,6 +182,12 @@ def status():
 @click.command(cls=BaseCommand, help="Create or refresh the configuration")
 @click.option("--user", prompt="Default username for running jobs using SOL", type=str, required=True,
               help="Set default user to run jobs on SOL.")
+@click.option("--workers", type=int, default=8,
+              help="Set default number of workers for issuing jobs on the server.")
+@click.option("--priority", type=click.Choice(["idle", "low", "high"]), default="low",
+              help="Set default priority to run jobs with.")
+@click.option("--cmd-files", type=str, multiple=True, default=(),
+              help="Set default command file(s) to use.")
 @click.option("--ssh-server", prompt="Default ssh DIAG deep learning server to use", type=str, required=True,
               help="Set default ssh DIAG deep learning server (dlc-machine.umcn.nl).")
 @click.option("--ssh-user", prompt="Default ssh username to use", type=str, required=True,
@@ -179,7 +197,7 @@ def status():
               help="Set default ssh password.")
 @click.option("-f", "--force", default=False, flag_value=True,
               help="Overwrite previous configuration file if it exists.")
-def create(user, ssh_server, ssh_user, ssh_pass, force):
+def create(user, workers, priority, cmd_files, ssh_server, ssh_user, ssh_pass, force):
     cfg = Config()
     if not cfg.is_config_present() or \
         force or\
@@ -188,7 +206,9 @@ def create(user, ssh_server, ssh_user, ssh_pass, force):
         cfgnew = {
             "defaults": {
                 "username": user,
-                "workers": 8
+                "workers": workers,
+                "priority": priority,
+                "cmdfiles": list(cmd_files)
             },
             "ssh": {
                 "server": ssh_server,
@@ -199,13 +219,13 @@ def create(user, ssh_server, ssh_user, ssh_pass, force):
             ]
         }
         click.echo(f"Writing configuration to: {cfg.config_path}")
-        os.makedirs(os.path.dirname(cfg.config_path))
+        os.makedirs(os.path.dirname(cfg.config_path), exist_ok=True)
         with open(cfg.config_path, "w") as f:
             json.dump(cfgnew, f)
         display_configuration(cfg=cfgnew)
 
 
-def display_configuration(cfg:Dict):
+def display_configuration(cfg: Dict):
     """Display configuration, but obscure the ssh password"""
     cfgcopy = copy.deepcopy(cfg)
     if "ssh" in cfgcopy and "password" in cfgcopy["ssh"]:
@@ -214,12 +234,14 @@ def display_configuration(cfg:Dict):
     pprint.pprint(cfgcopy)
 
 
+job.add_command(list_jobs)
+job.add_command(run)
+job.add_command(extend)
+job.add_command(stop)
+cli.add_command(job)
+
 config.add_command(status)
 config.add_command(create)
-cli.add_command(list)
-cli.add_command(run)
-cli.add_command(extend)
-cli.add_command(stop)
 cli.add_command(config)
 
 
