@@ -33,9 +33,13 @@ def resolve_cmd_files(cmd_files: List[str]) -> List[str]:
 
 
 def resolve_cmd_file(cmd_file: str) -> List[str]:
-    with open(cmd_file, 'r') as f:
-        data = f.readlines()
-    return [d.strip() for d in data if len(d.strip()) > 0 and d.strip()[0] != "#"]
+    try:
+        with open(cmd_file, 'r') as f:
+            data = f.readlines()
+        return [d.strip() for d in data if len(d.strip()) > 0 and d.strip()[0] != "#"]
+    except FileNotFoundError:
+        logger.error(f"ERROR: Could not find command file: {cmd_file}, skipping...")
+        return []
 
 
 def shared_section(cmd_files: List[str], cache_file: str, cfg: Config) \
@@ -130,6 +134,7 @@ def read_cache(file_name: str) -> Dict:
 
 
 def write_cache(file_name: str, data: Dict):
+    os.makedirs(os.path.dirname(file_name), exist_ok=True)
     with open(file_name, 'w') as f:
         json.dump(data, f)
 
@@ -190,7 +195,12 @@ def list_jobs(cmd_files, jobids, workers, cfg, cache_file, selected_only: bool =
 def run(cmd_files, jobids, workers, user, priority, reservation, duration, ignore_errors, cfg, cache_file):
     commands, cache, credentials = shared_section(cmd_files=cmd_files, cache_file=cache_file, cfg=cfg)
 
-    high_priority_job_available = not any([c.job_info is not None and c.get_job_priority() == 'high'
+    def _update_cmd(cmd):
+        cmd.update_job_info()
+
+    execute_commands(commands, map_fn=_update_cmd, workers=workers)
+
+    high_priority_job_available = not any([c.job_info is not None and c.get_job_priority() == 'high' and c.is_running()
                                            for c in commands if c.get_user() == user])
     if high_priority_job_available:
         logger.info(f'No high priority job running for user {user}!')
@@ -202,7 +212,8 @@ def run(cmd_files, jobids, workers, user, priority, reservation, duration, ignor
     subcmds = [cmd for idx, cmd in enumerate(commands) if idx + 1 in jobids]
 
     def _update_cmd(cmd):
-        cmd.update()
+        cmd.update_state()
+        cmd.update_errors()
 
     execute_commands(subcmds, map_fn=_update_cmd, workers=workers)
 
@@ -274,7 +285,7 @@ def setup_plugins(plugins: List[str], debug: bool = False) -> pluggy.PluginManag
 
 
 def validate_plugin(plugin):
-    required_fns = [e for e in dir(solitude.plugins.csubmit) if "__" not in e and "_" in e]
+    required_fns = [e for e in dir(solitude.plugins.default) if "__" not in e and "_" in e]
     for fn in required_fns:
         if not hasattr(plugin, fn):
             raise NotImplementedError(f"Plugin {plugin} has no hook_implementation for {fn}")
