@@ -3,15 +3,21 @@ from typing import Dict, List
 from solitude import hookimpl
 
 
+def filter_csubmit_command_str(cmd: str) -> str:
+    result = re.search(
+        r"c-submit\s+(?:--[\S-]+(?:=\S+)?\s+)*[\S]+\s+\S+\s\d+\s(\S+)(.*)", cmd.strip()
+    )
+    return (result.groups()[0] + result.groups()[1]).strip()
+
+
 @hookimpl
 def matches_command(cmd: str) -> bool:
-    return 'c-submit ' in cmd
+    return "c-submit " in cmd
 
 
 @hookimpl
-def filter_command_essential(cmd: str) -> str:
-    result = re.search(r"c-submit\s.*\s((?=doduo|oni)\S+\s.*)$", cmd.strip())
-    return result.groups()[0].strip()
+def get_command_hash(cmd: str) -> str:
+    return filter_csubmit_command_str(cmd=cmd)
 
 
 @hookimpl
@@ -26,16 +32,15 @@ def is_command_job_done(cmd: str, state: Dict) -> bool:
 
 @hookimpl
 def get_command_status_str(cmd: str, state: Dict) -> str:
-    result = re.search(r"c-submit\s.*\s((?=doduo|oni)\S+\s.*)$", cmd.strip())
-    return result.groups()[0].strip()
+    return filter_csubmit_command_str(cmd=cmd)
 
 
 @hookimpl
 def get_errors_from_log(log: str) -> List[str]:
     errors = []
-    if log.find('Killed') != -1:
+    if log.find("Killed") != -1:
         errors.append("NoResource")
-    if log.find('CUDA_ERROR') != -1:
+    if log.find("CUDA_ERROR") != -1:
         errors.append("CUDA")
-    errors = errors + [e[1:-1] for e in re.findall(r'\s.*Error:', log)]
+    errors = errors + [e[1:-1] for e in re.findall(r"\s.*Error:", log)]
     return errors
