@@ -9,7 +9,7 @@ def matches_command(cmd: str) -> bool:
 
 
 @hookimpl
-def filter_command_essential(cmd: str) -> str:
+def get_command_hash(cmd: str) -> str:
     return cmd
 
 
