@@ -1,7 +1,7 @@
-import re
 from typing import Dict, List
 from solitude import hookimpl
 from solitude.plugins.csubmit import get_errors_from_log as _get_errors_from_log
+from solitude.plugins.csubmit import filter_csubmit_command_str
 
 
 @hookimpl
@@ -10,9 +10,8 @@ def matches_command(cmd: str) -> bool:
 
 
 @hookimpl
-def filter_command_essential(cmd: str) -> str:
-    result = re.search(r"c-submit\s.*\s((?=doduo|oni)\S+\s.*)$", cmd.strip())
-    return result.groups()[0].strip()
+def get_command_hash(cmd: str) -> str:
+    return filter_csubmit_command_str(cmd=cmd)
 
 
 @hookimpl
@@ -27,8 +26,7 @@ def is_command_job_done(cmd: str, state: Dict) -> bool:
 
 @hookimpl
 def get_command_status_str(cmd: str, state: Dict) -> str:
-    result = re.search(r"c-submit\s.*\s((?=doduo|oni)\S+\s.*)$", cmd.strip())
-    return result.groups()[0].strip()
+    return filter_csubmit_command_str(cmd=cmd)
 
 
 @hookimpl
